@@ -7,8 +7,8 @@ import pandas as pd
 import sqlite3
 import random
 
-from parser import parse_fasta
-from preprocessor import Preprocessor
+from .parser import parse_fasta
+from .preprocessor import Preprocessor
 
 
 splits = []
@@ -187,7 +187,7 @@ class Matcher(Preprocessor):
     # compile all matches into format used for benchmarking (comma separated)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', '', '', ''))
+        all_matches.append((peptide, '', '', '', '', '', '', ''))
       for match in matches:
         # retrieve protein IDs from the other created table
         get_protein_data = 'SELECT * FROM "{names_table}" WHERE protein_number = "{protein_number}"'.format(
@@ -385,7 +385,7 @@ class Matcher(Preprocessor):
     # (peptide, matched peptide, protein matched in, index, # of mismatches)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', '', '', ''))
+        all_matches.append((peptide, '', '', '', '', '', '', ''))
       else:
         for match in matches:
           all_matches.append((
@@ -508,16 +508,16 @@ class Matcher(Preprocessor):
                                'Protein Name',
                                'Index start',
                                'Index end',
-                               'Protein Evidence Level',
+                               'Protein Existence Level',
                                'Gene Priority'])
     
     if self.one_match:
-      if df['Protein Evidence Level'].isnull().values.any():
+      if df['Protein Existence Level'].isnull().values.any():
         df.drop_duplicates(['Peptide Sequence'], inplace=True)
         return df
 
       else:
-        idx = df.groupby(['Peptide Sequence'])['Protein Evidence Level'].transform('min') == df['Protein Evidence Level']
+        idx = df.groupby(['Peptide Sequence'])['Protein Existence Level'].transform('min') == df['Protein Existence Level']
         df = df[idx]
 
       if df['Gene Priority'].isnull().values.any():
@@ -538,6 +538,7 @@ class Matcher(Preprocessor):
                       columns=['Peptide Sequence',
                                'Matched Peptide',
                                'Protein ID',
+                               'Protein Name',
                                'Mismatches',
                                'Mutated Positions',
                                'Index start',
