@@ -4,7 +4,7 @@ import pickle
 import sqlite3
 import re
 
-from parser import parse_fasta
+from .parser import parse_fasta
 
 
 class Preprocessor(object):
@@ -22,13 +22,13 @@ class Preprocessor(object):
   Optional: protein IDs can be versioned, so the versioned_ids argument can be passed
   as True to store them as versioned.
   '''
-  def __init__(self, 
-               proteome, 
-               split, 
-               preprocess_format, 
-               database='', 
-               one_gene_proteome='', 
-               source='uniprot', 
+  def __init__(self,
+               proteome,
+               split,
+               preprocess_format,
+               database='',
+               one_gene_proteome='',
+               source='uniprot',
                versioned_ids = False):
 
     if split < 2:
